import 'dart:collection';

import 'package:enge/makers/maker.dart';
import 'package:enge/support/io.dart';
import 'package:intl/intl.dart';
import 'package:slugify/slugify.dart';
import 'package:sprintf/sprintf.dart';

class MigrationMaker extends Maker {
  String name;

  MigrationMaker(String name) {
    this.name = name;
  }

  @override
  String getTemplateFileName() {
    return 'migration_template.template';
  }

  @override
  String getTargetPath() {
    final fileNamePattern = '%s_%s_migration.dart';

    var now = DateTime.now();
    var formatter = DateFormat('yyyy-MM-dd HH:mm:ss');

    var timestamp = formatter.format(now);
    timestamp = timestamp.replaceAll(' ', '_');
    timestamp = timestamp.replaceAll('-', '_');
    timestamp = timestamp.replaceAll(':', '_');

    var fileName = sprintf(fileNamePattern, [timestamp, this.name]);
    fileName = Slugify(fileName);

    return IO.joinOnWorkingDir('lib', 'database', 'migrations', fileName);
  }

  @override
  HashMap<String, String> getVariables() {
    final variables = HashMap<String, String>();
    variables['MIGRATION_NAME'] = this.name + 'Migration';

    return variables;
  }
}
